
DeNova Safecopy
---------------

Safecopy syncronizes drives and directories very carefully.
Like rsync, without rsync's insecure default metadata check.
Securely copies to and from remote filesystems through sshfs.


Full Description
----------------

Learn more about the denova python package at:

    https://denova.com/open/safecopy/
